Struct CryptoKeystore

pub struct CryptoKeystore { /* private fields */ }

Implementations

Source

impl Database

pub async fn open( location: ConnectionType<'_>, key: &DatabaseKey, ) -> Result<Database, CryptoKeystoreError>

pub async fn borrow_conn( &self, ) -> Result<MutexGuard<'_, SqlCipherConnection>, CryptoKeystoreError>

pub async fn export_copy( &self, destination_path: &str, ) -> Result<(), CryptoKeystoreError>

Export a copy of the database to the specified path. This creates a fully vacuumed and optimized copy of the database. The copy will be encrypted with the same key as the source database.

Platform Support

This method is only available on platforms using SQLCipher (not WASM).

Arguments
  • destination_path - The file path where the database copy should be created
Errors

Returns an error if:

  • The database is in-memory (cannot export in-memory databases)
  • The destination path is invalid
  • The export operation fails
pub async fn migrate_db_key_type_to_bytes( name: &str, old_key: &str, new_key: &DatabaseKey, ) -> Result<(), CryptoKeystoreError>

pub async fn update_key( &mut self, new_key: &DatabaseKey, ) -> Result<(), CryptoKeystoreError>

pub async fn wipe(self) -> Result<(), CryptoKeystoreError>

pub async fn close(self) -> Result<(), CryptoKeystoreError>

Wait for any running transaction to finish, then close the database connection.

pub async fn new_transaction(&self) -> Result<(), CryptoKeystoreError>

Waits for the current transaction to be committed or rolled back, then starts a new one.

pub async fn commit_transaction(&self) -> Result<(), CryptoKeystoreError>

pub async fn rollback_transaction(&self) -> Result<(), CryptoKeystoreError>

pub async fn child_groups<E>( &self, entity: E, ) -> Result<Vec<E>, CryptoKeystoreError>
where E: Entity<ConnectionType = SqlCipherConnection> + PersistedMlsGroupExt + Sync,

pub async fn save<E>(&self, entity: E) -> Result<E, CryptoKeystoreError>
where E: Entity<ConnectionType = SqlCipherConnection> + Sync + EntityTransactionExt,

pub async fn remove<E, S>(&self, id: S) -> Result<(), CryptoKeystoreError>
where E: Entity<ConnectionType = SqlCipherConnection> + EntityTransactionExt, S: AsRef<[u8]>,

pub async fn find_pending_messages_by_conversation_id( &self, conversation_id: &[u8], ) -> Result<Vec<MlsPendingMessage>, CryptoKeystoreError>

pub async fn remove_pending_messages_by_conversation_id( &self, conversation_id: &[u8], ) -> Result<(), CryptoKeystoreError>

pub async fn cred_delete_by_credential( &self, cred: Vec<u8>, ) -> Result<(), CryptoKeystoreError>